
/* Generated data (by glib-mkenums) */

#ifndef __KZ_BOOKMARKS_ENUM_TYPES_H__
#define __KZ_BOOKMARKS_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "kz-bookmark-file.h" */
GType kz_bookmark_file_flag_get_type (void);
#define KZ_TYPE_BOOKMARK_FILE_FLAG (kz_bookmark_file_flag_get_type())
GType kz_bookmark_file_state_get_type (void);
#define KZ_TYPE_BOOKMARK_FILE_STATE (kz_bookmark_file_state_get_type())
G_END_DECLS

#endif /* __KZ_BOOKMARKS_ENUM_TYPES_H__ */

/* Generated data ends here */

